@@ -39,13 +39,17 @@
  *
  */
 
+/**
+ * @file
+ */
+
 #ifndef LIST_H_
 #define LIST_H_
 
 #include <stddef.h>
 
-#include "common/container_of.h"
 #include "common/common_types.h"
+#include "common/container_of.h"
 
 /**
  * this struct is used as list head and list elements.
@@ -54,20 +58,16 @@
  * have a link to the head, no NULL element.
  */
 struct list_entity {
-  /**
-   * Pointer to next element in list or to list head if last element
-   */
+  /*! pointer to next element in list or to list head if last element */
   struct list_entity *next;
 
-  /**
-   * Pointer to previous element in list or list head if first element
-   */
+  /*! Pointer to previous element in list or list head if first element */
   struct list_entity *prev;
 };
 
 /**
  * initialize a list-head
- * @param pointer to list-head
+ * @param head to list-head
  */
 static INLINE void
 list_init_head(struct list_entity *head) {
@@ -76,7 +76,7 @@ list_init_head(struct list_entity *head) {
 
 /**
  * initialize a list-node
- * @param pointer to list-node
+ * @param entity to list-node
  */
 static INLINE void
 list_init_node(struct list_entity *entity) {
@@ -129,7 +129,7 @@ list_add_before(struct list_entity *before, struct list_entity *new) {
 
 /**
  * adds a node after another node
- * @param before reference node in the list
+ * @param after reference node in the list
  * @param new node which will be added to the list
  */
 static INLINE void
@@ -164,7 +164,7 @@ list_remove(struct list_entity *entity) {
  * @return true if list is empty, false otherwise
  */
 static INLINE bool
-list_is_empty(struct list_entity *head) {
+list_is_empty(const struct list_entity *head) {
   return head->next == head && head->prev == head;
 }
 
@@ -175,7 +175,7 @@ list_is_empty(struct list_entity *head) {
  *   false otherwise
  */
 static INLINE bool
-list_is_node_added(struct list_entity *node) {
+list_is_node_added(const struct list_entity *node) {
   return node->next != NULL && node->prev != NULL;
 }
 
@@ -213,10 +213,11 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
     return;
   }
 
-  add_to->next->prev = remove_from->prev;
-  remove_from->prev->next = add_to->next;
-  add_to->next = remove_from->next;
-  remove_from->next->prev = add_to;
+  add_to->prev->next = remove_from->next;
+  remove_from->next->prev = add_to->prev;
+
+  add_to->prev = remove_from->prev;
+  remove_from->prev->next = add_to;
 
   list_init_head(remove_from);
 }
@@ -230,8 +231,7 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @return pointer to the first element of the list
  *    (automatically converted to type 'element')
  */
-#define list_first_element(head, element, list_member) \
-    container_of((head)->next, typeof(*(element)), list_member)
+#define list_first_element(head, element, list_member) container_of((head)->next, typeof(*(element)), list_member)
 
 /**
  * @param head pointer to list-head
@@ -242,8 +242,7 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @return pointer to the last element of the list
  *    (automatically converted to type 'element')
  */
-#define list_last_element(head, element, list_member) \
-    container_of((head)->prev, typeof(*(element)), list_member)
+#define list_last_element(head, element, list_member) container_of((head)->prev, typeof(*(element)), list_member)
 
 /**
  * This function must not be called for the last element of
@@ -255,7 +254,7 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @return pointer to the node after 'element'
  *    (automatically converted to type 'element')
  */
-#define list_next_element(element, list_member) \
+#define list_next_element(element, list_member)                                                                        \
   container_of((&(element)->list_member)->next, typeof(*(element)), list_member)
 
 /**
@@ -268,7 +267,7 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @return pointer to the node before 'element'
  *    (automatically converted to type 'element')
  */
-#define list_prev_element(element, list_member) \
+#define list_prev_element(element, list_member)                                                                        \
   container_of((&(element)->list_member)->prev, typeof(*(element)), list_member)
 
 /**
@@ -281,9 +280,8 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param element iterator pointer to list element struct
  * @param list_member name of list_entity within list element struct
  */
-#define list_for_element_range(first_element, last_element, element, list_member) \
-  for (element = (first_element); \
-       element->list_member.prev != &(last_element)->list_member; \
+#define list_for_element_range(first_element, last_element, element, list_member)                                      \
+  for (element = (first_element); element->list_member.prev != &(last_element)->list_member;                           \
        element = list_next_element(element, list_member))
 
 /**
@@ -296,9 +294,8 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param element iterator pointer to list element struct
  * @param list_member name of list_entity within list element struct
  */
-#define list_for_element_range_reverse(first_element, last_element, element, list_member) \
-  for (element = (last_element); \
-       element->list_member.next != &(first_element)->list_member; \
+#define list_for_element_range_reverse(first_element, last_element, element, list_member)                              \
+  for (element = (last_element); element->list_member.next != &(first_element)->list_member;                           \
        element = list_prev_element(element, list_member))
 
 /**
@@ -312,10 +309,9 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param list_member name of the list_entity element inside the
  *    larger struct
  */
-#define list_for_each_element(head, element, list_member) \
-  list_for_element_range(list_first_element(head, element, list_member), \
-                         list_last_element(head, element, list_member), \
-                         element, list_member)
+#define list_for_each_element(head, element, list_member)                                                              \
+  list_for_element_range(list_first_element(head, element, list_member),                                               \
+    list_last_element(head, element, list_member), element, list_member)
 
 /**
  * Loop over all elements of a list backwards, used similar to a for() command.
@@ -328,10 +324,9 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param list_member name of the list_entity element inside the
  *    larger struct
  */
-#define list_for_each_element_reverse(head, element, list_member) \
-  list_for_element_range_reverse(list_first_element(head, element, list_member), \
-                                 list_last_element(head, element, list_member), \
-                                 element, list_member)
+#define list_for_each_element_reverse(head, element, list_member)                                                      \
+  list_for_element_range_reverse(list_first_element(head, element, list_member),                                       \
+    list_last_element(head, element, list_member), element, list_member)
 
 /**
  * Loop over a block of elements of a list, used similar to a for() command.
@@ -346,7 +341,7 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param list_member name of the list_entity element inside the
  *    larger struct
  */
-#define list_for_element_to_last(head, first, element, list_member) \
+#define list_for_element_to_last(head, first, element, list_member)                                                    \
   list_for_element_range(first, list_last_element(head, element, list_member), element, list_member)
 
 /**
@@ -362,7 +357,7 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param list_member name of the list_entity element inside the
  *    larger struct
  */
-#define list_for_element_to_last_reverse(head, first, element, list_member) \
+#define list_for_element_to_last_reverse(head, first, element, list_member)                                            \
   list_for_element_range_reverse(first, list_last_element(head, element, list_member), element, list_member)
 
 /**
@@ -378,7 +373,7 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param list_member name of the list_entity element inside the
  *    larger struct
  */
-#define list_for_first_to_element(head, last, element, list_member) \
+#define list_for_first_to_element(head, last, element, list_member)                                                    \
   list_for_element_range(list_first_element(head, element, list_member), last, element, list_member)
 
 /**
@@ -394,7 +389,7 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param list_member name of the list_entity element inside the
  *    larger struct
  */
-#define list_for_first_to_element_reverse(head, last, element, list_member) \
+#define list_for_first_to_element_reverse(head, last, element, list_member)                                            \
   list_for_element_range_reverse(list_first_element(head, element, list_member), last, element, list_member)
 
 /**
@@ -410,9 +405,9 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param ptr pointer to list element struct which is used to store
  *    the next node during the loop
  */
-#define list_for_element_range_safe(first_element, last_element, element, list_member, ptr) \
-  for (element = (first_element), ptr = list_next_element(element, list_member); \
-       element->list_member.prev != &(last_element)->list_member; \
+#define list_for_element_range_safe(first_element, last_element, element, list_member, ptr)                            \
+  for (element = (first_element), ptr = list_next_element(element, list_member);                                       \
+       element->list_member.prev != &(last_element)->list_member;                                                      \
        element = ptr, ptr = list_next_element(ptr, list_member))
 
 /**
@@ -428,9 +423,9 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param ptr pointer to list element struct which is used to store
  *    the previous node during the loop
  */
-#define list_for_element_range_reverse_safe(first_element, last_element, element, list_member, ptr) \
-  for (element = (last_element), ptr = list_prev_element(element, list_member); \
-       element->list_member.next != &(first_element)->list_member; \
+#define list_for_element_range_reverse_safe(first_element, last_element, element, list_member, ptr)                    \
+  for (element = (last_element), ptr = list_prev_element(element, list_member);                                        \
+       element->list_member.next != &(first_element)->list_member;                                                     \
        element = ptr, ptr = list_prev_element(ptr, list_member))
 
 /**
@@ -447,10 +442,9 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param ptr pointer to an list element struct which is used to store
  *    the next node during the loop
  */
-#define list_for_each_element_safe(head, element, list_member, ptr) \
-  list_for_element_range_safe(list_first_element(head, element, list_member), \
-                              list_last_element(head, element, list_member), \
-                              element, list_member, ptr)
+#define list_for_each_element_safe(head, element, list_member, ptr)                                                    \
+  list_for_element_range_safe(list_first_element(head, element, list_member),                                          \
+    list_last_element(head, element, list_member), element, list_member, ptr)
 
 /**
  * Loop over all elements of a list backwards, used similar to a for() command.
@@ -466,9 +460,8 @@ list_merge(struct list_entity *add_to, struct list_entity *remove_from) {
  * @param ptr pointer to an list element struct which is used to store
  *    the next node during the loop
  */
-#define list_for_each_element_reverse_safe(head, element, list_member, ptr) \
-  list_for_element_range_reverse_safe(list_first_element(head, element, list_member), \
-                                      list_last_element(head, element, list_member), \
-                                      element, list_member, ptr)
+#define list_for_each_element_reverse_safe(head, element, list_member, ptr)                                            \
+  list_for_element_range_reverse_safe(list_first_element(head, element, list_member),                                  \
+    list_last_element(head, element, list_member), element, list_member, ptr)
 
 #endif /* LIST_H_ */
