@@ -71,24 +71,23 @@
 #include <sys/socket.h>
 
 /* and now the rest of the includes */
-#include <linux/types.h>
-#include <linux/netlink.h>
-#include <linux/genetlink.h>
 #include "nl80211.h"
+#include <linux/genetlink.h>
+#include <linux/netlink.h>
+#include <linux/types.h>
 #include <netlink/attr.h>
-#include <netlink/msg.h>
 #include <netlink/genl/genl.h>
+#include <netlink/msg.h>
 
 #include "common/common_types.h"
 #include "subsystems/oonf_clock.h"
 #include "subsystems/os_system.h"
 
+#include "nl80211_listener/nl80211_get_station_dump.h"
 #include "nl80211_listener/nl80211_internal.h"
 #include "nl80211_listener/nl80211_listener.h"
-#include "nl80211_listener/nl80211_get_station_dump.h"
 
-static bool _handle_traffic(struct oonf_layer2_neigh *l2neigh,
-    enum oonf_layer2_neighbor_index idx, uint32_t new_32bit);
+static bool _handle_traffic(struct oonf_layer2_neigh *l2neigh, enum oonf_layer2_neighbor_index idx, uint32_t new_32bit);
 static int64_t _get_bitrate(struct nlattr *bitrate_attr);
 
 /**
@@ -99,16 +98,15 @@ static int64_t _get_bitrate(struct nlattr *bitrate_attr);
  * @param interf nl80211 listener interface
  */
 void
-nl80211_send_get_station_dump(struct os_system_netlink *nl,
-    struct nlmsghdr *nl_msg, struct genlmsghdr *hdr, struct nl80211_if *interf) {
-  int if_index = nl80211_get_if_index(interf);
+nl80211_send_get_station_dump(
+  struct os_system_netlink *nl, struct nlmsghdr *nl_msg, struct genlmsghdr *hdr, struct nl80211_if *interf) {
+  int if_index = nl80211_get_if_baseindex(interf);
 
   hdr->cmd = NL80211_CMD_GET_STATION;
   nl_msg->nlmsg_flags |= NLM_F_DUMP;
 
   /* add interface index to the request */
-  os_system_linux_netlink_addreq(nl, nl_msg, NL80211_ATTR_IFINDEX,
-      &if_index, sizeof(if_index));
+  os_system_linux_netlink_addreq(nl, nl_msg, NL80211_ATTR_IFINDEX, &if_index, sizeof(if_index));
 }
 
 /**
@@ -117,8 +115,7 @@ nl80211_send_get_station_dump(struct os_system_netlink *nl,
  * @param hdr pointer to netlink message header
  */
 void
-nl80211_process_get_station_dump_result(struct nl80211_if *interf,
-    struct nlmsghdr *hdr) {
+nl80211_process_get_station_dump_result(struct nl80211_if *interf, struct nlmsghdr *hdr) {
   struct oonf_layer2_neigh *l2neigh;
   struct netaddr l2neigh_mac;
 
@@ -136,8 +133,7 @@ nl80211_process_get_station_dump_result(struct nl80211_if *interf,
     [NL80211_STA_INFO_RX_BITRATE] = { .type = NLA_NESTED },
     [NL80211_STA_INFO_TX_RETRIES] = { .type = NLA_U32 },
     [NL80211_STA_INFO_TX_FAILED] = { .type = NLA_U32 },
-    [NL80211_STA_INFO_STA_FLAGS] =
-      { .minlen = sizeof(struct nl80211_sta_flag_update) },
+    [NL80211_STA_INFO_STA_FLAGS] = { .minlen = sizeof(struct nl80211_sta_flag_update) },
   };
 #ifdef OONF_LOG_DEBUG_INFO
   struct netaddr_str nbuf;
@@ -145,29 +141,25 @@ nl80211_process_get_station_dump_result(struct nl80211_if *interf,
 
   gnlh = nlmsg_data(hdr);
 
-  nla_parse(tb, NL80211_ATTR_MAX, genlmsg_attrdata(gnlh, 0),
-      genlmsg_attrlen(gnlh, 0), NULL);
+  nla_parse(tb, NL80211_ATTR_MAX, genlmsg_attrdata(gnlh, 0), genlmsg_attrlen(gnlh, 0), NULL);
 
   if (!tb[NL80211_ATTR_STA_INFO]) {
     /* station info missing */
     return;
   }
-  if (nla_parse_nested(sinfo, NL80211_STA_INFO_MAX,
-           tb[NL80211_ATTR_STA_INFO],
-           stats_policy)) {
+  if (nla_parse_nested(sinfo, NL80211_STA_INFO_MAX, tb[NL80211_ATTR_STA_INFO], stats_policy)) {
     /* no nested attributes */
     return;
   }
 
-  if (nl80211_get_if_index(interf) != nla_get_u32(tb[NL80211_ATTR_IFINDEX])) {
+  if (nl80211_get_if_baseindex(interf) != nla_get_u32(tb[NL80211_ATTR_IFINDEX])) {
     /* wrong interface */
     return;
   }
 
   netaddr_from_binary(&l2neigh_mac, nla_data(tb[NL80211_ATTR_MAC]), 6, AF_MAC48);
 
-  OONF_DEBUG(LOG_NL80211, "Received Station Dump for %s",
-      netaddr_to_string(&nbuf, &l2neigh_mac));
+  OONF_DEBUG(LOG_NL80211, "Received Station Dump for %s", netaddr_to_string(&nbuf, &l2neigh_mac));
 
   l2neigh = oonf_layer2_neigh_add(interf->l2net, &l2neigh_mac);
   if (!l2neigh) {
@@ -176,51 +168,42 @@ nl80211_process_get_station_dump_result(struct nl80211_if *interf,
   }
 
   if (sinfo[NL80211_STA_INFO_INACTIVE_TIME]) {
-    l2neigh->last_seen = oonf_clock_get_absolute(
-      -((int64_t)(nla_get_u32(sinfo[NL80211_STA_INFO_INACTIVE_TIME]))));
+    l2neigh->last_seen = oonf_clock_get_absolute(-((int64_t)(nla_get_u32(sinfo[NL80211_STA_INFO_INACTIVE_TIME]))));
   }
 
   /* byte data is 64 bit */
   if (sinfo[NL80211_STA_INFO_RX_BYTES64]) {
-    nl80211_change_l2neigh_data(l2neigh, OONF_LAYER2_NEIGH_RX_BYTES,
-        nla_get_u64(sinfo[NL80211_STA_INFO_RX_BYTES64]));
+    nl80211_change_l2neigh_data(l2neigh, OONF_LAYER2_NEIGH_RX_BYTES, nla_get_u64(sinfo[NL80211_STA_INFO_RX_BYTES64]));
   }
   if (sinfo[NL80211_STA_INFO_TX_BYTES64]) {
-    nl80211_change_l2neigh_data(l2neigh, OONF_LAYER2_NEIGH_TX_BYTES,
-        nla_get_u64(sinfo[NL80211_STA_INFO_TX_BYTES64]));
+    nl80211_change_l2neigh_data(l2neigh, OONF_LAYER2_NEIGH_TX_BYTES, nla_get_u64(sinfo[NL80211_STA_INFO_TX_BYTES64]));
   }
 
   /* packet data is only 32 bit */
   if (sinfo[NL80211_STA_INFO_RX_PACKETS]) {
-    _handle_traffic(l2neigh, OONF_LAYER2_NEIGH_RX_FRAMES,
-      nla_get_u32(sinfo[NL80211_STA_INFO_RX_PACKETS]));
+    _handle_traffic(l2neigh, OONF_LAYER2_NEIGH_RX_FRAMES, nla_get_u32(sinfo[NL80211_STA_INFO_RX_PACKETS]));
   }
   if (sinfo[NL80211_STA_INFO_TX_PACKETS]) {
-    _handle_traffic(l2neigh, OONF_LAYER2_NEIGH_TX_FRAMES,
-        nla_get_u32(sinfo[NL80211_STA_INFO_TX_PACKETS]));
+    _handle_traffic(l2neigh, OONF_LAYER2_NEIGH_TX_FRAMES, nla_get_u32(sinfo[NL80211_STA_INFO_TX_PACKETS]));
   }
   if (sinfo[NL80211_STA_INFO_TX_RETRIES]) {
-    _handle_traffic(l2neigh, OONF_LAYER2_NEIGH_TX_RETRIES,
-        nla_get_u32(sinfo[NL80211_STA_INFO_TX_RETRIES]));
+    _handle_traffic(l2neigh, OONF_LAYER2_NEIGH_TX_RETRIES, nla_get_u32(sinfo[NL80211_STA_INFO_TX_RETRIES]));
   }
   if (sinfo[NL80211_STA_INFO_TX_FAILED]) {
-    _handle_traffic(l2neigh, OONF_LAYER2_NEIGH_TX_FAILED,
-        nla_get_u32(sinfo[NL80211_STA_INFO_TX_FAILED]));
+    _handle_traffic(l2neigh, OONF_LAYER2_NEIGH_TX_FAILED, nla_get_u32(sinfo[NL80211_STA_INFO_TX_FAILED]));
   }
 
   /* bitrates are special */
   if (sinfo[NL80211_STA_INFO_TX_BITRATE]) {
     int64_t rate = _get_bitrate(sinfo[NL80211_STA_INFO_TX_BITRATE]);
     if (rate) {
-      nl80211_change_l2neigh_data(l2neigh,
-          OONF_LAYER2_NEIGH_TX_BITRATE, rate);
+      nl80211_change_l2neigh_data(l2neigh, OONF_LAYER2_NEIGH_TX_BITRATE, rate);
     }
   }
   if (sinfo[NL80211_STA_INFO_RX_BITRATE]) {
     int64_t rate = _get_bitrate(sinfo[NL80211_STA_INFO_RX_BITRATE]);
     if (rate) {
-      nl80211_change_l2neigh_data(l2neigh,
-                OONF_LAYER2_NEIGH_RX_BITRATE, rate);
+      nl80211_change_l2neigh_data(l2neigh, OONF_LAYER2_NEIGH_RX_BITRATE, rate);
     }
   }
 
@@ -231,8 +214,7 @@ nl80211_process_get_station_dump_result(struct nl80211_if *interf,
     rate = nla_get_u32(sinfo[NL80211_STA_INFO_EXPECTED_THROUGHPUT]);
 
     /* convert in bps */
-    nl80211_change_l2neigh_data(l2neigh,
-              OONF_LAYER2_NEIGH_TX_THROUGHPUT, rate * 1024ll);
+    nl80211_change_l2neigh_data(l2neigh, OONF_LAYER2_NEIGH_TX_THROUGHPUT, rate * 1024ll);
   }
 
   /* signal strength is special too */
@@ -240,8 +222,7 @@ nl80211_process_get_station_dump_result(struct nl80211_if *interf,
     int8_t signal;
 
     signal = nla_get_u8(sinfo[NL80211_STA_INFO_SIGNAL]);
-    nl80211_change_l2neigh_data(l2neigh,
-        OONF_LAYER2_NEIGH_RX_SIGNAL, signal * 1000ll);
+    nl80211_change_l2neigh_data(l2neigh, OONF_LAYER2_NEIGH_RX_SIGNAL, signal * 1000ll);
   }
 
   /* remove old data */
@@ -252,39 +233,34 @@ nl80211_process_get_station_dump_result(struct nl80211_if *interf,
 }
 
 static bool
-_handle_traffic(struct oonf_layer2_neigh *l2neigh,
-    enum oonf_layer2_neighbor_index idx, uint32_t new_32bit) {
+_handle_traffic(struct oonf_layer2_neigh *l2neigh, enum oonf_layer2_neighbor_index idx, uint32_t new_32bit) {
   static const uint64_t UPPER_32_MASK = 0xffffffff00000000ull;
   static const uint64_t LOWER_32_MASK = 0x00000000ffffffffull;
   struct oonf_layer2_data *data;
-  uint64_t old_value, new_value;
+  int64_t old_value, new_value;
 
   new_value = 0;
   old_value = 0;
 
   data = &l2neigh->data[idx];
-  if (oonf_layer2_has_value(data)) {
-    old_value = oonf_layer2_get_value(data);
-  }
+  oonf_layer2_data_read_int64(&old_value, data);
 
   new_value = old_value & UPPER_32_MASK;
   new_value |= (new_32bit & LOWER_32_MASK);
 
-  OONF_DEBUG(LOG_NL80211, "new32: 0x%08x old: %016"PRIx64 " new: %016"PRIx64,
-      new_32bit, old_value, new_value);
+  OONF_DEBUG(LOG_NL80211, "new32: 0x%08x old: %016" PRIx64 " new: %016" PRIx64, new_32bit, old_value, new_value);
 
-  if (new_value + 0x80000000ull < old_value) {
+  if (new_value + 0x80000000ll < old_value) {
     /* handle 32bit counter overflow */
-    new_value += 0x100000000ull;
-    OONF_DEBUG(LOG_NL80211, "Overflow, new: %016"PRIx64, new_value);
+    new_value += 0x100000000ll;
+    OONF_DEBUG(LOG_NL80211, "Overflow, new: %016" PRIx64, new_value);
   }
 
   return nl80211_change_l2neigh_data(l2neigh, idx, new_value);
 }
 
 static int64_t
-_get_bitrate(struct nlattr *bitrate_attr)
-{
+_get_bitrate(struct nlattr *bitrate_attr) {
   int rate = 0;
   struct nlattr *rinfo[NL80211_RATE_INFO_MAX + 1];
   static struct nla_policy rate_policy[NL80211_RATE_INFO_MAX + 1] = {
@@ -292,8 +268,7 @@ _get_bitrate(struct nlattr *bitrate_attr)
     [NL80211_RATE_INFO_BITRATE32] = { .type = NLA_U32 },
   };
 
-  if (nla_parse_nested(rinfo, NL80211_RATE_INFO_MAX,
-           bitrate_attr, rate_policy)) {
+  if (nla_parse_nested(rinfo, NL80211_RATE_INFO_MAX, bitrate_attr, rate_policy)) {
     /* error in parsing bitrate nested arguments */
     return 0;
   }
