@@ -43,9 +43,9 @@
  * @file
  */
 
-#include "common/common_types.h"
 #include "common/avl.h"
 #include "common/avl_comp.h"
+#include "common/common_types.h"
 #include "common/list.h"
 #include "common/netaddr.h"
 
@@ -53,11 +53,11 @@
 #include "subsystems/oonf_class.h"
 #include "subsystems/oonf_timer.h"
 
-#include "nhdp/nhdp_internal.h"
+#include "nhdp/nhdp_db.h"
+#include "nhdp/nhdp_domain.h"
 #include "nhdp/nhdp_hysteresis.h"
 #include "nhdp/nhdp_interfaces.h"
-#include "nhdp/nhdp_domain.h"
-#include "nhdp/nhdp_db.h"
+#include "nhdp/nhdp_internal.h"
 
 /* Prototypes of local functions */
 static void _link_status_now_symmetric(struct nhdp_link *lnk);
@@ -71,10 +71,10 @@ static void _cb_l2hop_vtime(struct oonf_timer_instance *);
 static void _cb_naddr_vtime(struct oonf_timer_instance *);
 
 /* Link status names */
-static const char *_LINK_PENDING   = "pending";
-static const char *_LINK_HEARD     = "heard";
+static const char *_LINK_PENDING = "pending";
+static const char *_LINK_HEARD = "heard";
 static const char *_LINK_SYMMETRIC = "symmetric";
-static const char *_LINK_LOST      = "lost";
+static const char *_LINK_LOST = "lost";
 
 /* memory and timer classes necessary for NHDP */
 static struct oonf_class _neigh_info = {
@@ -232,14 +232,16 @@ nhdp_db_neighbor_add(void) {
  */
 void
 nhdp_db_neighbor_remove(struct nhdp_neighbor *neigh) {
+  struct nhdp_neighbor_domaindata *neighdata;
   struct nhdp_naddr *naddr, *na_it;
   struct nhdp_link *lnk, *l_it;
+  struct nhdp_domain *domain;
 #ifdef OONF_LOG_DEBUG_INFO
   struct netaddr_str nbuf;
 #endif
+  bool was_mpr;
 
-  OONF_DEBUG(LOG_NHDP, "Remove Neighbor: 0x%0zx (%s)",
-      (size_t)neigh, netaddr_to_string(&nbuf, &neigh->originator));
+  OONF_DEBUG(LOG_NHDP, "Remove Neighbor: 0x%0zx (%s)", (size_t)neigh, netaddr_to_string(&nbuf, &neigh->originator));
 
   /* trigger event */
   oonf_class_event(&_neigh_info, neigh, OONF_OBJECT_REMOVED);
@@ -262,6 +264,21 @@ nhdp_db_neighbor_remove(struct nhdp_neighbor *neigh) {
     avl_remove(&_neigh_originator_tree, &neigh->_originator_node);
   }
 
+  /* check if neighbor was a MPR */
+  was_mpr = false;
+  list_for_each_element(nhdp_domain_get_list(), domain, _node) {
+    neighdata = nhdp_domain_get_neighbordata(domain, neigh);
+    if (neighdata->neigh_is_mpr) {
+      was_mpr = true;
+      break;
+    }
+  }
+
+  if (was_mpr) {
+    /* all domains might have changed */
+    nhdp_domain_delayed_mpr_recalculation(NULL, neigh);
+  }
+
   /* remove from global list and free memory */
   list_remove(&neigh->_global_node);
   oonf_class_free(&_neigh_info, neigh);
@@ -342,8 +359,7 @@ nhdp_db_neighbor_join(struct nhdp_neighbor *dst, struct nhdp_neighbor *src) {
  * @return pointer to neighbor address, NULL if out of memory
  */
 struct nhdp_naddr *
-nhdp_db_neighbor_addr_add(struct nhdp_neighbor *neigh,
-    const struct netaddr *addr) {
+nhdp_db_neighbor_addr_add(struct nhdp_neighbor *neigh, const struct netaddr *addr) {
   struct nhdp_naddr *naddr;
 
   naddr = oonf_class_malloc(&_naddr_info);
@@ -394,8 +410,8 @@ nhdp_db_neighbor_addr_remove(struct nhdp_naddr *naddr) {
 
 /**
  * Moves a nhdp neighbor address to a different neighbor
- * @param neigh
- * @param naddr
+ * @param neigh nhdp neighbor
+ * @param naddr nhdp neighbor address
  */
 void
 nhdp_db_neighbor_addr_move(struct nhdp_neighbor *neigh, struct nhdp_naddr *naddr) {
@@ -415,8 +431,7 @@ nhdp_db_neighbor_addr_move(struct nhdp_neighbor *neigh, struct nhdp_naddr *naddr
  * @param originator originator address, might be type AF_UNSPEC
  */
 void
-nhdp_db_neighbor_set_originator(struct nhdp_neighbor *neigh,
-    const struct netaddr *originator) {
+nhdp_db_neighbor_set_originator(struct nhdp_neighbor *neigh, const struct netaddr *originator) {
   struct nhdp_neighbor *neigh2;
   struct nhdp_link *lnk;
 
@@ -460,6 +475,12 @@ nhdp_db_neighbor_set_originator(struct nhdp_neighbor *neigh,
       avl_insert(&lnk->local_if->_link_originators, &lnk->_originator_node);
     }
   }
+
+  /* inform everyone */
+  oonf_class_event(&_neigh_info, neigh, OONF_OBJECT_CHANGED);
+
+  /* overwrite "old originator" */
+  memcpy(&neigh->_old_originator, originator, sizeof(*originator));
 }
 
 /**
@@ -468,9 +489,7 @@ nhdp_db_neighbor_set_originator(struct nhdp_neighbor *neigh,
  * @param n_ipv6 ipv6 neighbor
  */
 void
-nhdp_db_neighbor_connect_dualstack(
-    struct nhdp_neighbor *n_ipv4, struct nhdp_neighbor *n_ipv6) {
-
+nhdp_db_neighbor_connect_dualstack(struct nhdp_neighbor *n_ipv4, struct nhdp_neighbor *n_ipv6) {
   if (n_ipv4->dualstack_partner != n_ipv6) {
     nhdp_db_neigbor_disconnect_dualstack(n_ipv4);
     n_ipv4->dualstack_partner = n_ipv6;
@@ -682,8 +701,8 @@ nhdp_db_link_addr_remove(struct nhdp_laddr *laddr) {
 
 /**
  * Moves a nhdp link address to a different link
- * @param lnk
- * @param laddr
+ * @param lnk NHDP link
+ * @param laddr NHDP link address
  */
 void
 nhdp_db_link_addr_move(struct nhdp_link *lnk, struct nhdp_laddr *laddr) {
@@ -772,9 +791,7 @@ nhdp_db_link_2hop_remove(struct nhdp_l2hop *l2hop) {
  * @param l_ipv6 ipv6 link
  */
 void
-nhdp_db_link_connect_dualstack(
-    struct nhdp_link *l_ipv4, struct nhdp_link *l_ipv6) {
-
+nhdp_db_link_connect_dualstack(struct nhdp_link *l_ipv4, struct nhdp_link *l_ipv6) {
   if (l_ipv4->dualstack_partner != l_ipv6) {
     nhdp_db_link_disconnect_dualstack(l_ipv4);
     l_ipv4->dualstack_partner = l_ipv6;
@@ -812,6 +829,7 @@ nhdp_db_link_update_status(struct nhdp_link *lnk) {
   was_symmetric = lnk->status == NHDP_LINK_SYMMETRIC;
 
   /* update link status */
+  lnk->last_status = lnk->status;
   lnk->status = _nhdp_db_link_calculate_status(lnk);
 
   /* handle database changes */
@@ -830,6 +848,8 @@ nhdp_db_link_update_status(struct nhdp_link *lnk) {
   if (old_status != lnk->status) {
     /* link status was changed */
     lnk->last_status_change = oonf_clock_getNow();
+    nhdp_domain_recalculate_metrics(NULL, lnk->neigh);
+    nhdp_domain_delayed_mpr_recalculation(NULL, lnk->neigh);
 
     /* trigger change event */
     oonf_class_event(&_link_info, lnk, OONF_OBJECT_CHANGED);
@@ -897,6 +917,31 @@ nhdp_db_get_neigh_originator_tree(void) {
  */
 int
 _nhdp_db_link_calculate_status(struct nhdp_link *lnk) {
+  const struct netaddr *local_originator;
+  const struct os_interface *localif;
+  int af_type;
+
+  af_type = netaddr_get_address_family(&lnk->if_addr);
+  local_originator = nhdp_get_originator(af_type);
+  localif = nhdp_interface_get_if_listener(lnk->local_if)->data;
+
+  /* check for originator collision */
+  if (!netaddr_is_unspec(local_originator) && (netaddr_cmp(local_originator, &lnk->if_addr) == 0 ||
+                                                netaddr_cmp(local_originator, &lnk->neigh->originator) == 0)) {
+    return NHDP_LINK_PENDING;
+  }
+
+  /* check for interface address collision */
+  if (nhdp_interface_addr_if_get(lnk->local_if, &lnk->if_addr)) {
+    return NHDP_LINK_PENDING;
+  }
+
+  /* check for MAC collision */
+  if (netaddr_cmp(&localif->mac, &lnk->remote_mac) == 0) {
+    return NHDP_LINK_PENDING;
+  }
+
+  /* calculate link status as described in RFC 6130 */
   if (nhdp_hysteresis_is_pending(lnk))
     return NHDP_LINK_PENDING;
   if (nhdp_hysteresis_is_lost(lnk))
@@ -975,10 +1020,6 @@ _cb_link_vtime(struct oonf_timer_instance *ptr) {
   /* check if neighbor still has links */
   if (list_is_empty(&neigh->_links)) {
     nhdp_db_neighbor_remove(neigh);
-    nhdp_domain_neighborhood_changed();
-  }
-  else {
-    nhdp_domain_neighbor_changed(neigh);
   }
 }
 
@@ -1006,7 +1047,6 @@ _cb_link_symtime(struct oonf_timer_instance *ptr) {
   lnk = container_of(ptr, struct nhdp_link, sym_time);
   OONF_DEBUG(LOG_NHDP, "Link Symtime fired: 0x%0zx", (size_t)lnk);
   nhdp_db_link_update_status(lnk);
-  nhdp_domain_neighbor_changed(lnk->neigh);
 }
 
 /**
@@ -1030,12 +1070,9 @@ _cb_naddr_vtime(struct oonf_timer_instance *ptr) {
 static void
 _cb_l2hop_vtime(struct oonf_timer_instance *ptr) {
   struct nhdp_l2hop *l2hop;
-  struct nhdp_neighbor *neigh;
 
   l2hop = container_of(ptr, struct nhdp_l2hop, _vtime);
-  neigh = l2hop->link->neigh;
 
   OONF_DEBUG(LOG_NHDP, "2Hop vtime fired: 0x%0zx", (size_t)ptr);
   nhdp_db_link_2hop_remove(l2hop);
-  nhdp_domain_neighbor_changed(neigh);
 }
